# CHANGELOG

<!-- version list -->

## v1.0.5 (2026-04-01)

### Bug Fixes

- Stream records to avoid OOMs
  ([`a28d481`](https://github.com/celine-eu/pg_freezer/commit/a28d481adb05d6b1c753eb0e12d4e6e25baa14f2))

### Chores

- Update pkg
  ([`cf70ee1`](https://github.com/celine-eu/pg_freezer/commit/cf70ee1fd9b8e9c0bcdeba42c3f2d368a783ce74))


## v1.0.4 (2026-03-27)

### Bug Fixes

- PENDING, EXCUTING states inconsistencies
  ([`b0e1e15`](https://github.com/celine-eu/pg_freezer/commit/b0e1e15d32507048f553fe11b2b136f339e5d201))


## v1.0.3 (2026-03-27)

### Bug Fixes

- Corrected monthly to not overlap end date lag
  ([`95ab403`](https://github.com/celine-eu/pg_freezer/commit/95ab40353468ad4a474cdf123af12f9447c3ca68))

### Chores

- Update image refs
  ([`cf35d04`](https://github.com/celine-eu/pg_freezer/commit/cf35d04025ccd97fca186cce7ae311e974880875))

### Continuous Integration

- Bump hynek/build-and-inspect-python-package in the actions group
  ([`70e788e`](https://github.com/celine-eu/pg_freezer/commit/70e788ee32bcf85b71cbf1169a2851cdaef11c09))


## v1.0.2 (2026-03-27)

### Bug Fixes

- Corrected dockerfile
  ([`2cca5b1`](https://github.com/celine-eu/pg_freezer/commit/2cca5b1f144979407dfd965a7808ff6d4ff4264a))


## v1.0.1 (2026-03-27)

### Bug Fixes

- Add long description
  ([`671dc29`](https://github.com/celine-eu/pg_freezer/commit/671dc29e235f517f996f470a4fa185fc516f15dc))

### Chores

- Update gh pipeline
  ([`a063c5f`](https://github.com/celine-eu/pg_freezer/commit/a063c5fa22a8af0cd02ab7c7e369b38bd8efe83d))

- Update GH release yml
  ([`0f8e410`](https://github.com/celine-eu/pg_freezer/commit/0f8e410891376c4647436da7fd3a60f04b1db659))


## v1.0.0 (2026-03-27)

- Initial Release
